@@ -252,7 +252,7 @@ class TestCase(unittest.TestCase):
             "-e", "@/etc/kayobe/vars-file1.yml",
             "-e", "@/etc/kayobe/vars-file2.yaml",
             "-e", "ev_name1=ev_value1",
-            "-e", "ev_name2=ev_value2",
+            "-e", "ev_name2='ev_value2'",
             "--check",
             "--limit", "group1:host1:&group2:host2",
             "--tags", "tag1,tag2,tag3,tag4",
@@ -264,35 +264,6 @@ class TestCase(unittest.TestCase):
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with("/etc/kayobe")
 
-    @mock.patch.object(utils, "run_command")
-    @mock.patch.object(ansible, "_get_vars_files")
-    @mock.patch.object(ansible, "_validate_args")
-    def test_run_playbooks_ignore_limit(self, mock_validate, mock_vars,
-                                        mock_run):
-        mock_vars.return_value = ["/etc/kayobe/vars-file1.yml",
-                                  "/etc/kayobe/vars-file2.yaml"]
-        parser = argparse.ArgumentParser()
-        ansible.add_args(parser)
-        vault.add_args(parser)
-        args = [
-            "-l", "group1:host",
-        ]
-        parsed_args = parser.parse_args(args)
-        ansible.run_playbooks(parsed_args, ["playbook1.yml", "playbook2.yml"],
-                              limit="foo", ignore_limit=True)
-        expected_cmd = [
-            "ansible-playbook",
-            "--inventory", "/etc/kayobe/inventory",
-            "-e", "@/etc/kayobe/vars-file1.yml",
-            "-e", "@/etc/kayobe/vars-file2.yaml",
-            "playbook1.yml",
-            "playbook2.yml",
-        ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe"}
-        mock_run.assert_called_once_with(expected_cmd, check_output=False,
-                                         quiet=False, env=expected_env)
-        mock_vars.assert_called_once_with("/etc/kayobe")
-
     @mock.patch.object(utils, "run_command")
     @mock.patch.object(ansible, "_get_vars_files")
     @mock.patch.object(ansible, "_validate_args")
@@ -314,8 +285,7 @@ class TestCase(unittest.TestCase):
                          mock_rmtree):
         parser = argparse.ArgumentParser()
         parsed_args = parser.parse_args([])
-        dump_dir = "/path/to/dump"
-        mock_mkdtemp.return_value = dump_dir
+        dump_dir = mock_mkdtemp.return_value
         mock_listdir.return_value = ["host1.yml", "host2.yml"]
         mock_read.side_effect = [
             {"var1": "value1"},
@@ -327,15 +297,17 @@ class TestCase(unittest.TestCase):
             "host2": {"var2": "value2"},
         }
         self.assertEqual(result, expected_result)
+        dump_config_path = utils.get_data_files_path(
+            "ansible", "dump-config.yml")
         mock_run.assert_called_once_with(parsed_args,
-                                         "ansible/dump-config.yml",
+                                         dump_config_path,
                                          extra_vars={
                                              "dump_path": dump_dir,
                                          },
                                          check_output=True, tags=None,
                                          verbose_level=None, check=False)
         mock_rmtree.assert_called_once_with(dump_dir)
-        mock_listdir.assert_called_once_with(dump_dir)
+        mock_listdir.assert_any_call(dump_dir)
         mock_read.assert_has_calls([
             mock.call(os.path.join(dump_dir, "host1.yml")),
             mock.call(os.path.join(dump_dir, "host2.yml")),
@@ -353,8 +325,9 @@ class TestCase(unittest.TestCase):
 
         ansible.install_galaxy_roles(parsed_args)
 
-        mock_install.assert_called_once_with("requirements.yml",
-                                             "ansible/roles", force=False)
+        mock_install.assert_called_once_with(utils.get_data_files_path(
+            "requirements.yml"), utils.get_data_files_path(
+            "ansible", "roles"), force=False)
         mock_is_readable.assert_called_once_with(
             "/etc/kayobe/ansible/requirements.yml")
         self.assertFalse(mock_mkdirs.called)
@@ -372,7 +345,9 @@ class TestCase(unittest.TestCase):
         ansible.install_galaxy_roles(parsed_args)
 
         expected_calls = [
-            mock.call("requirements.yml", "ansible/roles", force=False),
+            mock.call(utils.get_data_files_path("requirements.yml"),
+                      utils.get_data_files_path("ansible", "roles"),
+                      force=False),
             mock.call("/etc/kayobe/ansible/requirements.yml",
                       "/etc/kayobe/ansible/roles", force=False)]
         self.assertEqual(expected_calls, mock_install.call_args_list)
@@ -393,7 +368,9 @@ class TestCase(unittest.TestCase):
         ansible.install_galaxy_roles(parsed_args, force=True)
 
         expected_calls = [
-            mock.call("requirements.yml", "ansible/roles", force=True),
+            mock.call(utils.get_data_files_path("requirements.yml"),
+                      utils.get_data_files_path("ansible", "roles"),
+                      force=True),
             mock.call("/etc/kayobe/ansible/requirements.yml",
                       "/etc/kayobe/ansible/roles", force=True)]
         self.assertEqual(expected_calls, mock_install.call_args_list)
@@ -415,8 +392,9 @@ class TestCase(unittest.TestCase):
         self.assertRaises(exception.Error,
                           ansible.install_galaxy_roles, parsed_args)
 
-        mock_install.assert_called_once_with("requirements.yml",
-                                             "ansible/roles", force=False)
+        mock_install.assert_called_once_with(utils.get_data_files_path(
+            "requirements.yml"), utils.get_data_files_path("ansible", "roles"),
+            force=False)
         mock_is_readable.assert_called_once_with(
             "/etc/kayobe/ansible/requirements.yml")
         mock_mkdirs.assert_called_once_with("/etc/kayobe/ansible/roles")
@@ -437,29 +415,3 @@ class TestCase(unittest.TestCase):
         ]
         mock_remove.assert_called_once_with(expected_roles,
                                             "ansible/roles")
-
-    @mock.patch.object(utils, 'is_readable_file', autospec=True)
-    def test_passwords_yml_exists_false(self, mock_is_readable):
-        parser = argparse.ArgumentParser()
-        ansible.add_args(parser)
-        parsed_args = parser.parse_args([])
-        mock_is_readable.return_value = {"result": False}
-
-        result = ansible.passwords_yml_exists(parsed_args)
-
-        self.assertFalse(result)
-        mock_is_readable.assert_called_once_with(
-            "/etc/kayobe/kolla/passwords.yml")
-
-    @mock.patch.object(utils, 'is_readable_file', autospec=True)
-    def test_passwords_yml_exists_true(self, mock_is_readable):
-        parser = argparse.ArgumentParser()
-        ansible.add_args(parser)
-        parsed_args = parser.parse_args(["--config-path", "/path/to/config"])
-        mock_is_readable.return_value = {"result": True}
-
-        result = ansible.passwords_yml_exists(parsed_args)
-
-        self.assertTrue(result)
-        mock_is_readable.assert_called_once_with(
-            "/path/to/config/kolla/passwords.yml")
